@@ -3,7 +3,7 @@ import asyncio
 import json
 from collections import deque
 
-SPLUNK_PAYLOAD_LIMIT = 262144  # 256KB, Actual limit is 512KB
+SPLUNK_PAYLOAD_LIMIT = 512000  # 500KB, Actual limit is 512KB/880MB depending on version.
 
 class SplunkPayloadError(aiohttp.ClientPayloadError):
     def __init__(self,code,message,status):
@@ -24,7 +24,7 @@ class hass_splunk:
         use_ssl=True,
         verify_ssl=True,
         endpoint="collector/event",
-        timeout=5,
+        timeout=60,
     ):
         self.session = session
         self.url = f"{['http','https'][use_ssl]}://{host}:{port}/services/{endpoint}"
@@ -76,7 +76,7 @@ class hass_splunk:
                         if "code" not in reply or "text" not in reply:
                             resp.raise_for_status()
                         if reply["code"] != 0:
-                            if resp.status != 400: # Dont reque on status 400
+                            if resp.status in [500, 503]: # Only retry on server errors
                                 self.batch = events + self.batch
                             raise SplunkPayloadError(code=reply["code"],message=reply["text"],status=resp.status)
                         
@@ -88,7 +88,19 @@ class hass_splunk:
         return True
 
     async def check(self, connectivity=True, token=True, busy=True):
-        codes = {
+        try:
+            async with self.session.post(
+                self.url,
+                ssl=self.verify_ssl,
+                headers=self.headers,
+                timeout=self.timeout,
+            ) as resp:
+                reply = await resp.json()
+        except (aiohttp.ClientConnectionError,asyncio.TimeoutError):
+            return not connectivity
+        except Exception:
+            return False
+        return {
             0: True,  # Success
             1: not token,  # Token disabled
             2: not token,  # Token is required
@@ -106,17 +118,4 @@ class hass_splunk:
             14: None,  # ACK is disabled
             15: None,  # Error in handling indexed fields
             16: None,  # Query string authorization is not enabled
-        }
-        try:
-            async with self.session.post(
-                self.url,
-                ssl=self.verify_ssl,
-                headers=self.headers,
-                timeout=self.timeout,
-            ) as resp:
-                reply = await resp.json()
-        except (aiohttp.ClientConnectionError,asyncio.TimeoutError):
-            return not connectivity
-        except Exception:
-            return False
-        return codes.get(reply["code"], False)
+        }.get(reply["code"], False)
